@@ -81,5 +81,5 @@ else
   ontape -s -L 0 >> ${LOGFILE} 2>&1
   BAKSTATUS=$?
   loginfo "Execute backup finished with CODE: ${BAKSTATUS}"
-  exit 1
+  exit ${BAKSTATUS}
 fi
